package
Version:
v0.0.0-...-83bb8b4
Opens a new window with list of versions in this module.
Published: Jul 22, 2017
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type EncodedMsg struct {
Timestamp string `json:"timestamp"`
MessageType string `json:"type"`
Network string `json:"network"`
Data []string `json:"data"`
Id string `json:"id"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.